# Imuthes

Collection of tools (most in sub-packages). 

Logging implemented via [Hakisto](https://pypi.org/project/hakisto).

## Top Level Tools

### Classes 

#### Mapping

Convenience abstract class for simple mapping. Inherit and implement `__init__`.

#### NamedMapping

Mapping that makes items available as attributes.

#### Singleton

Thread safe singleton class. Add as a super-class.

---

- alchemy
- sap

